@@ -70,6 +70,11 @@ class ModuleTests(TestCase):
                                 'version': '0.1'}
                          )
 
+        info = get_info_from_module(Module('moduleunimportabledouble', samples_dir))
+        self.assertEqual(info, {'summary': 'A sample unimportable module with double assignment',
+                                'version': '0.1'}
+                         )
+
         info = get_info_from_module(Module('module1', samples_dir / 'constructed_version'))
         self.assertEqual(info, {'summary': 'This module has a __version__ that requires runtime interpretation',
                                 'version': '1.2.3'}
@@ -113,6 +118,9 @@ def test_normalize_file_permissions():
         ("<4, > 3.2", False),
         (">3.4", False),
         (">=2.7, !=3.0.*, !=3.1.*, !=3.2.*", True),
+        ("== 3.9", False),
+        ("~=2.7", True),
+        ("~=3.9", False),
     ],
 )
 def test_supports_py2(requires_python, expected_result):
